@@ -919,7 +919,6 @@ main (int argc,
     GApplication *app;
     gint retval;
     GError *error = NULL;
-    GOptionContext *ctx;
 
     bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -928,27 +927,8 @@ main (int argc,
     if (!FcInit ())
         g_critical ("Can't initialize fontconfig library");
 
-    ctx = g_option_context_new (_("[FILE...]"));
-    g_option_context_add_main_entries (ctx, goption_options, PACKAGE);
-    g_option_context_add_group (ctx, gtk_get_option_group (FALSE));
-
-    if (!g_option_context_parse (ctx, &argc, &argv, &error)) {
-        gchar *help_msg;
-
-        /* I18N: The '%s' is replaced with the command name. */
-        help_msg = g_strdup_printf (_("Run '%s --help' to see a full "
-                                      "list of available command line "
-                                      "options."), argv[0]);
-        g_printerr ("%s\n%s\n", error->message, help_msg);
-        g_error_free (error);
-        g_free (help_msg);
-        g_option_context_free (ctx);
-
-        return EXIT_FAILURE;
-    }
-    g_option_context_free (ctx);
-
     app = font_view_application_new ();
+    g_application_add_main_option_entries (app, goption_options);
     retval = g_application_run (app, argc, argv);
 
     g_object_unref (app);
